# PatchedModelRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str, none_type** |  | [optional] 
**status** | **str** |  | [optional] 
**source** | **str** |  | [optional] 
**world_position** | **[float], none_type** | [x,y,z] array of the position of the local_placement in world coordinates | [optional] 
**size_ratio** | **float, none_type** | How many meters a unit represents | [optional] 
**archived** | **bool** |  | [optional] 
**version** | **str, none_type** | This field is only for information. Updating it won&#39;t impact the export. | [optional] 
**north_vector** | **[[float]], none_type** | This field is only for information. Updating it won&#39;t impact the export. | [optional] 
**recommanded_2d_angle** | **float, none_type** | This is the angle in clockwise degree to apply on the 2D to optimise the horizontality of objects. This field is only for information. Updating it won&#39;t impact the export. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


